@@ -7,7 +7,7 @@ use Carp;
 use Statistics::Lite qw(min max mean);
 use Bio::DB::BigWig qw(binMean binStdev);
 use Bio::DB::BigWigSet;
-our $VERSION = '1.14';
+our $VERSION = '1.15';
 
 
 # Exported names
@@ -24,12 +24,6 @@ our @EXPORT = qw(
 );
 
 
-# Hashes of opened file objects
-our %OPENED_BIGFILES; # opened bigwig file objects
-	# in empirical testing, this doesn't really seem to speed things up
-	# like I thought it would
-	# oh well, keep it anyway????
-
 # Hash of Bigfile chromosomes
 our %BIGWIG_CHROMOS;
 	# sometimes user may request a chromosome that's not in the bigfile
@@ -37,6 +31,10 @@ our %BIGWIG_CHROMOS;
 	# we will record the chromosomes list in this hash
 	# $BIGWIG_CHROMOS{bigfile}{chromos}
 
+# Opened bigWig db objects
+our %OPENED_BW;
+	# a cache for opened BigWig databases, primarily for collecting scores
+
 # The true statement
 1; 
 
@@ -67,8 +65,18 @@ sub collect_bigwig_score {
 	foreach my $wig (@wig_files) {
 		
 		# open a new db object
-		my $bw = open_bigwig_db($wig) or 
-			croak " Unable to open bigWig file '$wig'! $!\n";
+		my $bw;
+		if (exists $OPENED_BW{$wig}) {
+			# use a cached object
+			$bw = $OPENED_BW{$wig};
+		}
+		else {
+			# open and cache the bigWig object
+			$bw = open_bigwig_db($wig) or 
+				croak " Unable to open bigWig file '$wig'! $!\n";
+			$OPENED_BW{$wig} = $bw;
+			%{ $BIGWIG_CHROMOS{$wig} } = map { $_ => 1 } $bw->seq_ids;
+		}
 		
 		# first check that the chromosome is present
 		if (exists $BIGWIG_CHROMOS{$wig}{$chromo}) {
@@ -114,8 +122,18 @@ sub collect_bigwig_scores {
 	foreach my $wig (@wig_files) {
 	
 		# Open the BigWig file
-		my $bw = open_bigwig_db($wig) or 
-			croak " Unable to open bigWig file '$wig'! $!\n";;
+		my $bw;
+		if (exists $OPENED_BW{$wig}) {
+			# use a cached object
+			$bw = $OPENED_BW{$wig};
+		}
+		else {
+			# open and cache the bigWig object
+			$bw = open_bigwig_db($wig) or 
+				croak " Unable to open bigWig file '$wig'! $!\n";
+			$OPENED_BW{$wig} = $bw;
+			%{ $BIGWIG_CHROMOS{$wig} } = map { $_ => 1 } $bw->seq_ids;
+		}
 		
 		# first check that the chromosome is present
 		unless (exists $BIGWIG_CHROMOS{$wig}{$chromo}) {
@@ -162,8 +180,18 @@ sub collect_bigwig_position_scores {
 	foreach my $wig (@wig_files) {
 	
 		# Open the BigWig file
-		my $bw = open_bigwig_db($wig) or 
-			croak " Unable to open bigWig file '$wig'! $!\n";;
+		my $bw;
+		if (exists $OPENED_BW{$wig}) {
+			# use a cached object
+			$bw = $OPENED_BW{$wig};
+		}
+		else {
+			# open and cache the bigWig object
+			$bw = open_bigwig_db($wig) or 
+				croak " Unable to open bigWig file '$wig'! $!\n";
+			$OPENED_BW{$wig} = $bw;
+			%{ $BIGWIG_CHROMOS{$wig} } = map { $_ => 1 } $bw->seq_ids;
+		}
 		
 		# first check that the chromosome is present
 		unless (exists $BIGWIG_CHROMOS{$wig}{$chromo}) {
@@ -565,30 +593,17 @@ sub collect_bigwigset_position_scores {
 ### Open a bigWig database connection
 sub open_bigwig_db {
 	
+	# path
 	my $wigfile = shift;
+	my $path = $wigfile;
+	$path =~ s/^file://; # clean up file prefix if present
+	
+	# open
 	my $bw;
-	
-	# check whether the file has been opened or not
-	if (exists $OPENED_BIGFILES{$wigfile} ) {
-		# this file is already opened, use it
-		$bw = $OPENED_BIGFILES{$wigfile};
-	}
-	
-	else {
-		# this file has not been opened yet, open it
-		my $path = $wigfile;
-		$path =~ s/^file://; # clean up file prefix if present
-		eval {
-			$bw = Bio::DB::BigWig->new( -bigwig => $path);
-		};
-		return unless $bw;
-		
-		# store the opened object for later use
-		$OPENED_BIGFILES{$wigfile} = $bw;
-		
-		# collect the chromosomes for this bigwig
-		%{ $BIGWIG_CHROMOS{$wigfile} } = map { $_ => 1 } $bw->seq_ids;
-	}
+	eval {
+		$bw = Bio::DB::BigWig->new( -bigwig => $path);
+	};
+	return unless $bw;
 	
 	return $bw;
 }
@@ -631,6 +646,24 @@ sub open_bigwigset_db {
 		# collect the chromosomes for this bigwig
 		%{ $BIGWIG_CHROMOS{$paths[0]} } = map { $_ => 1 } $bw->seq_ids;
 		
+		# check for potential implied strandedness
+		my $md = $bws->metadata;
+		foreach my $i (keys %$md) {
+			my $f = $md->{$i}{'dbid'}; # the file path
+			if ($f =~ /(?:f|for|forward|top|plus|\+)\.bw$/i) {
+				# implied forward strand 
+				unless (exists $md->{$i}{'strand'}) {
+					$bws->set_bigwig_attributes($f, {'strand' => 1});
+				}
+			}
+			elsif ($f =~ /(?:r|rev|reverse|bottom|minus|\-)\.bw$/i) {
+				# implied reverse strand 
+				unless (exists $md->{$i}{'strand'}) {
+					$bws->set_bigwig_attributes($f, {'strand' => -1});
+				}
+			}
+		}
+		
 		return $bws;
 	}
 	else {
@@ -843,10 +876,6 @@ script 'big_file2gff3.pl'. This will prepare either a GFF3 file for loading
 into a Bio::DB::SeqFeature::Store database, or a Bio::DB::BigWigSet 
 database.
 
-To speed up the program and avoid repetitive opening and 
-closing of the files, the opened bigwig file object is stored in a global 
-hash in case it is needed again.
-
 When a single score is requested for a region, then a special low-level 
 statistical method is employed to significantly reduce data collection 
 times. Up to a ten fold improvement or better has been observed over the 
