@@ -1,4 +1,4 @@
-#!/usr/bin/env perl
+#!/usr/bin/perl
 
 # documentation at end of file
 
@@ -11,7 +11,7 @@ use Bio::ToolBox::file_helper qw(
 	open_tim_data_file
 	open_to_write_fh
 );
-my $VERSION = '1.14';
+my $VERSION = '1.15';
 
 print "\n This program will write a BED file\n";
 
@@ -513,10 +513,13 @@ The command line flags and descriptions:
 
 =item --in <filename>
 
-Specify the file name of a data file. It must be a tab-delimited text file,
-preferably in the tim data format as described in Bio::ToolBox::file_helper, 
-although any format should work. The file may be compressed with gzip. 
-Sam files will not work, see L<bam2gff_bed.pl> for that.
+Specify an input file containing either a list of database features or 
+genomic coordinates for which to collect data. The file should be a 
+tab-delimited text file, one row per feature, with columns representing 
+feature identifiers, attributes, coordinates, and/or data values. Genome 
+coordinates are required. The first row should be column headers. Text 
+files generated by other B<BioToolBox> scripts are acceptable. Files may 
+be gzipped compressed.
 
 =item --ask
 
@@ -591,10 +594,11 @@ Alternatively, provide a name of a database, below.
 
 =item --db <database>
 
-Specify the database from which chromosome lengths can be derived when 
-generating a BigBed file. This option is only required when generating 
-BigBed files. It may also be supplied from the metadata in the source 
-data file.
+Specify the name of a C<Bio::DB::SeqFeature::Store> annotation database 
+or other indexed data file, e.g. Bam or bigWig file, from which chromosome 
+length information may be obtained. For more information about using databases, 
+see L<https://code.google.com/p/biotoolbox/wiki/WorkingWithDatabases>. It 
+may be supplied from the input file metadata.
 
 =item --bbapp </path/to/bedToBigBed>
 
