@@ -1,4 +1,4 @@
-#!/usr/bin/env perl
+#!/usr/bin/perl
 
 # documentation at end of file
 
@@ -19,7 +19,7 @@ use Bio::ToolBox::file_helper qw(
 	open_to_read_fh
 	write_tim_data_file
 );
-my $VERSION = '1.14';
+my $VERSION = '1.15';
 
 print "\n This program will get specific regions from features\n\n";
 
@@ -1047,8 +1047,12 @@ The command line flags and descriptions:
 
 =item --db <text>
 
-Specify the name of a BioPerl SeqFeature::Store database to use as an 
-annotation source. 
+Specify the name of a C<Bio::DB::SeqFeature::Store> annotation database 
+from which gene or feature annotation may be derived. A database is 
+required for generating new data files with features. For more information 
+about using annotation databases, 
+see L<https://code.google.com/p/biotoolbox/wiki/WorkingWithDatabases>. 
+Also see C<--in> as an alternative.
 
 =item --in <filename>
 
